@@ -1200,6 +1200,7 @@
         MessageType["UI_SAVE_FILE"] = "ui-save-file";
         MessageType["UI_REQUEST_EXPORT_CSS"] = "ui-request-export-css";
         MessageType["UI_COLOR_SCHEME_CHANGE"] = "ui-color-scheme-change";
+        MessageType["UI_HIDE_HIGHLIGHTS"] = "ui-hide-highlights";
         MessageType["BG_CHANGES"] = "bg-changes";
         MessageType["BG_ADD_CSS_FILTER"] = "bg-add-css-filter";
         MessageType["BG_ADD_STATIC_THEME"] = "bg-add-static-theme";
@@ -1278,19 +1279,22 @@
         }
     })();
     (() => {
-        if (typeof document === "undefined") {
-            return false;
-        }
-        const el = document.createElement("div");
-        if (typeof el.style.colorScheme === "string") {
-            return true;
-        }
         try {
+            if (typeof document === "undefined") {
+                return false;
+            }
+            const el = document.createElement("div");
+            if (!el || typeof el.style !== "object") {
+                return false;
+            }
+            if (typeof el.style.colorScheme === "string") {
+                return true;
+            }
             el.setAttribute("style", "color-scheme: dark");
+            return el.style.colorScheme === "dark";
         } catch (e) {
             return false;
         }
-        return el.style && el.style.colorScheme === "dark";
     })();
 
     function classes(...args) {
@@ -2400,51 +2404,57 @@
             return compareIPV6(url, urlTemplate);
         } else if (!isFirstIPV6 && !isSecondIPV6) {
             const regex = createUrlRegex(urlTemplate);
-            return Boolean(url.match(regex));
+            return regex !== null && Boolean(url.match(regex));
         }
         return false;
     }
     function createUrlRegex(urlTemplate) {
-        urlTemplate = urlTemplate.trim();
-        const exactBeginning = urlTemplate[0] === "^";
-        const exactEnding = urlTemplate[urlTemplate.length - 1] === "$";
-        const hasLastSlash = /\/\$?$/.test(urlTemplate);
-        urlTemplate = urlTemplate
-            .replace(/^\^/, "")
-            .replace(/\$$/, "")
-            .replace(/^.*?\/{2,3}/, "")
-            .replace(/\?.*$/, "")
-            .replace(/\/$/, "");
-        let slashIndex;
-        let beforeSlash;
-        let afterSlash;
-        if ((slashIndex = urlTemplate.indexOf("/")) >= 0) {
-            beforeSlash = urlTemplate.substring(0, slashIndex);
-            afterSlash = urlTemplate.replace(/\$/g, "").substring(slashIndex);
-        } else {
-            beforeSlash = urlTemplate.replace(/\$/g, "");
-        }
-        let result = exactBeginning
-            ? "^(.*?\\:\\/{2,3})?"
-            : "^(.*?\\:\\/{2,3})?([^/]*?\\.)?";
-        const hostParts = beforeSlash.split(".");
-        result += "(";
-        for (let i = 0; i < hostParts.length; i++) {
-            if (hostParts[i] === "*") {
-                hostParts[i] = "[^\\.\\/]+?";
+        try {
+            urlTemplate = urlTemplate.trim();
+            const exactBeginning = urlTemplate[0] === "^";
+            const exactEnding = urlTemplate[urlTemplate.length - 1] === "$";
+            const hasLastSlash = /\/\$?$/.test(urlTemplate);
+            urlTemplate = urlTemplate
+                .replace(/^\^/, "")
+                .replace(/\$$/, "")
+                .replace(/^.*?\/{2,3}/, "")
+                .replace(/\?.*$/, "")
+                .replace(/\/$/, "");
+            let slashIndex;
+            let beforeSlash;
+            let afterSlash;
+            if ((slashIndex = urlTemplate.indexOf("/")) >= 0) {
+                beforeSlash = urlTemplate.substring(0, slashIndex);
+                afterSlash = urlTemplate
+                    .replace(/\$/g, "")
+                    .substring(slashIndex);
+            } else {
+                beforeSlash = urlTemplate.replace(/\$/g, "");
             }
-        }
-        result += hostParts.join("\\.");
-        result += ")";
-        if (afterSlash) {
+            let result = exactBeginning
+                ? "^(.*?\\:\\/{2,3})?"
+                : "^(.*?\\:\\/{2,3})?([^/]*?\\.)?";
+            const hostParts = beforeSlash.split(".");
             result += "(";
-            result += afterSlash.replace("/", "\\/");
+            for (let i = 0; i < hostParts.length; i++) {
+                if (hostParts[i] === "*") {
+                    hostParts[i] = "[^\\.\\/]+?";
+                }
+            }
+            result += hostParts.join("\\.");
             result += ")";
+            if (afterSlash) {
+                result += "(";
+                result += afterSlash.replace("/", "\\/");
+                result += ")";
+            }
+            result += exactEnding
+                ? "(\\/?(\\?[^/]*?)?)$"
+                : `(\\/${hasLastSlash ? "" : "?"}.*?)$`;
+            return new RegExp(result, "i");
+        } catch (e) {
+            return null;
         }
-        result += exactEnding
-            ? "(\\/?(\\?[^/]*?)?)$"
-            : `(\\/${hasLastSlash ? "" : "?"}.*?)$`;
-        return new RegExp(result, "i");
     }
 
     function Body({data, actions}) {
@@ -2663,6 +2673,12 @@
                 type: MessageType.UI_RESET_DEV_STATIC_THEMES
             });
         }
+        async hideHighlights(ids) {
+            chrome.runtime.sendMessage({
+                type: MessageType.UI_HIDE_HIGHLIGHTS,
+                data: ids
+            });
+        }
         disconnect() {
             if (this.changeSubscribers.size > 0) {
                 this.changeSubscribers.clear();
